@@ -39,7 +39,7 @@ const (
 	// Minimum required version of the sandbox plugin code.  The first part is
 	// the version of the incorporated Nimbella CLI and the second part is the
 	// version of the bridge code in the sandbox plugin repository.
-	minSandboxVersion = "3.0.10-1.2.1"
+	minSandboxVersion = "3.1.1-1.2.1"
 
 	// The version of nodejs to download alongsize the plugin download.
 	nodeVersion = "v16.13.0"
@@ -91,12 +91,11 @@ func Sandbox() *Command {
 	cmd := &Command{
 		Command: &cobra.Command{
 			Use:   "sandbox",
-			Short: "[Beta] Develop functions in a sandbox prior to deploying them in an app",
+			Short: "Develop functions in a sandbox prior to deploying them in an app",
 			Long: `The ` + "`" + `doctl sandbox` + "`" + ` commands provide a development sandbox for functions.  A sandbox has a local file system component and a cloud component.
 A one-time install of the sandbox software is needed (use ` + "`" + `doctl sandbox install` + "`" + ` to install the software, then ` + "`" + `doctl sandbox connect` + "`" + ` to
 connect to the cloud component of the sandbox provided with your account).  Other ` + "`" + `doctl sandbox` + "`" + ` commands are used to develop and test.`,
 			Aliases: []string{"sbx", "serverless", "sls"},
-			Hidden:  !isSandboxInstalled(),
 		},
 	}
 
@@ -625,12 +624,6 @@ func getCurrentSandboxVersion(sandboxDir string) string {
 	return string(contents)
 }
 
-// Answers whether sandbox is installed
-func isSandboxInstalled() bool {
-	_, yes := getSandboxDirectory()
-	return yes
-}
-
 // Gets the version of the node binary in the sandbox.  Determine if it is
 // usable or whether it has to be upgraded.
 func canReuseNode(sandboxDir string, nodeBin string) bool {
